@@ -37,9 +37,9 @@
 
 /* Useful in particular for loadshared where the full path
  * to the lib is needed */
-#define GDCM_SOURCE_DIR "C:/M/B/src/GDCM-3.0.24"
-#define GDCM_EXECUTABLE_OUTPUT_PATH "C:/M/B/src/build-shared-CLANGARM64/bin"
-#define GDCM_LIBRARY_OUTPUT_PATH    "C:/M/B/src/build-shared-CLANGARM64/bin"
+#define GDCM_SOURCE_DIR "C:/W/B/src/GDCM-3.0.24"
+#define GDCM_EXECUTABLE_OUTPUT_PATH "C:/W/B/src/build-shared-CLANGARM64/bin"
+#define GDCM_LIBRARY_OUTPUT_PATH    "C:/W/B/src/build-shared-CLANGARM64/bin"
 
 /* #undef GDCM_BUILD_TESTING */
 
